Range-v3: ranges::v3::concepts::CallableTransform Struct Reference

Range-v3 Range algorithms, views, and actions for the Standard Library |

Public Member Functions | List of all members
ranges::v3::concepts::CallableTransform Struct Reference
Inheritance diagram for ranges::v3::concepts::CallableTransform:

## Public Member Functions
template<typename Fun , typename T >
auto | requires_ (Fun &&, T &&) -> decltype( concepts::valid_expr( concepts::model_of< Transform, function_type< Fun >, T >() ))
Public Member Functions inherited from ranges::v3::concepts::refines< RegularCallable >
void | requires_ (Ts &&...)

## Additional Inherited Members
Public Types inherited from ranges::v3::concepts::refines< RegularCallable >
using | base_concepts_t = meta::list< Concepts... >